@@ -3,6 +3,7 @@ import logging
 import operator
 import functools
 import numpy as np
+import yaml
 from typing import Set
 from typing import Callable
 from typing import Iterable
@@ -15,13 +16,13 @@ from polygenic.lib.data_access.allele_frequency_accessor import AlleleFrequencyA
 from polygenic.seqql.category import validate_categories_names
 from polygenic.seqql.category import validate_categories_ranges
 from polygenic.seqql.category import QuantitativeCategory
-from polygenic.lib.data_access.data_accessor import VcfAccessor
+from polygenic.lib.data_access.vcf_accessor import VcfAccessor
+from polygenic.lib.data_access.vcf_accessor import DataNotPresentError
 from polygenic.lib.data_access.dto import SnpData
-from polygenic.lib.data_access.data_accessor import DataNotPresentError
+
 
 logger = logging.getLogger('description_language.' + __name__)
 
-
 class FunctionData(NamedTuple):
     function_to_apply_on_allele_pair: Callable
     function_to_apply_between_allele_pairs: Callable
@@ -83,6 +84,7 @@ class PolygenicRiskScoreResult(NamedTuple):
     scaled_result: float
     category: str
     boundaries: Dict[str, Dict[str, float]]
+    genotypes: dict
 
 
 class Data(object):
@@ -169,6 +171,11 @@ class Data(object):
                     f'Either rsid: {rsid} or population: {self._population} not found in allele frequency data')
                 self._rsids_absent_in_allele_freq_data.add(rsid)
                 continue
+            except WrongAlleleInModelError:
+                logger.debug(
+                    f'Rsid {rsid} has bad effect allele'
+                )
+                continue
 
 
     def compute_model(self) -> PolygenicRiskScoreResult:
@@ -214,7 +221,8 @@ class Data(object):
             result_for_model,
             get_category(self._model.categories, result_for_model).scale_cat(result_for_model),
             get_category(self._model.categories, result_for_model).name,
-            category_boundaries
+            category_boundaries,
+            genotypes = {}
         )
 
 
